==> integration-tests-jobs-service-springboot-1.26.1-20220823.031908-5-sources.jar: org/acme/travels/AsyncModelInput.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import org.kie.kogito.MapInput;
import org.kie.kogito.MapInputId;
import org.kie.kogito.MapOutput;
import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.MappableToModel;
import org.kie.kogito.Model;
import org.kie.kogito.ProcessInput;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "async", name = "Async", hidden = true)
@ProcessInput(processName = "async")
public class AsyncModelInput implements Model, MapInput, MapInputId, MapOutput, MappableToModel<AsyncModel> {

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "name")
    @javax.validation.Valid()
    private java.lang.String name;

    public java.lang.String getName() {
        return name;
    }

    public void setName(java.lang.String name) {
        this.name = name;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "hello")
    @javax.validation.Valid()
    private java.lang.String hello;

    public java.lang.String getHello() {
        return hello;
    }

    public void setHello(java.lang.String hello) {
        this.hello = hello;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "bye")
    @javax.validation.Valid()
    private java.lang.String bye;

    public java.lang.String getBye() {
        return bye;
    }

    public void setBye(java.lang.String bye) {
        this.bye = bye;
    }

    @Override()
    public AsyncModel toModel() {
        AsyncModel result = new AsyncModel();
        result.setName(getName());
        result.setHello(getHello());
        result.setBye(getBye());
        return result;
    }
}

==> integration-tests-jobs-service-springboot-3.0.0-20231201.044652-1-sources.jar: org/acme/travels/AsyncModelInput.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import org.kie.kogito.MapInput;
import org.kie.kogito.MapInputId;
import org.kie.kogito.MapOutput;
import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.MappableToModel;
import org.kie.kogito.Model;
import org.kie.kogito.ProcessInput;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "async", name = "Async", hidden = true)
@ProcessInput(processName = "async")
public class AsyncModelInput implements Model, MapInput, MapInputId, MapOutput, MappableToModel<AsyncModel> {

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "name")
    @jakarta.validation.Valid()
    private java.lang.String name;

    public java.lang.String getName() {
        return name;
    }

    public void setName(java.lang.String name) {
        this.name = name;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "hello")
    @jakarta.validation.Valid()
    private java.lang.String hello;

    public java.lang.String getHello() {
        return hello;
    }

    public void setHello(java.lang.String hello) {
        this.hello = hello;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "bye")
    @jakarta.validation.Valid()
    private java.lang.String bye;

    public java.lang.String getBye() {
        return bye;
    }

    public void setBye(java.lang.String bye) {
        this.bye = bye;
    }

    @Override()
    public AsyncModel toModel() {
        AsyncModel result = new AsyncModel();
        result.setName(getName());
        result.setHello(getHello());
        result.setBye(getBye());
        return result;
    }
}
